@@ -15,37 +15,32 @@
 #'   term was used to model either the `"mean"` or `"precision"`. Here the
 #'   precision is the inverse of the variance, often referred to as `phi`.
 #'   At least one term will have been used to model the precision `phi`.
-#' 
+#'
 #'   The `vars` package does not include a `confint` method and does not report
 #'   confidence intervals for `varest` objects. Setting the `tidy` argument
 #'   `conf.int = TRUE` will return a warning.
 #'
-#' @examples
-#' 
-#' # feel free to ignore the following line—it allows {broom} to supply 
-#' # examples without requiring the model-supplying package to be installed.
-#' if (requireNamespace("vars", quietly = TRUE)) {
-#' 
+#' @examplesIf rlang::is_installed("vars")
+#'
 #' # load libraries for models and data
 #' library(vars)
-#' 
+#'
 #' # load data
 #' data("Canada", package = "vars")
-#' 
+#'
 #' # fit models
 #' mod <- VAR(Canada, p = 1, type = "both")
-#' 
+#'
 #' # summarize model fit with tidiers
 #' tidy(mod)
 #' glance(mod)
-#' 
-#' }
-#' 
+#'
 #' @export
 #' @seealso [tidy()], [vars::VAR()]
 #' @family vars tidiers
 #' @aliases vars_tidiers
 tidy.varest <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
+  check_ellipses("exponentiate", "tidy", "varest", ...)
 
   # `vars` does not define a `confint` method and does not calculate CIs
   if (isTRUE(conf.int)) {
@@ -55,17 +50,17 @@ tidy.varest <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
   s <- summary(x)
 
   ret <- list()
-  
+
   for (v in names(s$varresult)) {
     ret[[v]] <- as_tidy_tibble(
-      s$varresult[[1]]$coefficients,
+      s$varresult[[v]]$coefficients,
       new_names = c("estimate", "std.error", "statistic", "p.value")
     )
     ret[[v]]$group <- v
   }
-  
+
   ret <- dplyr::bind_rows(ret) %>%
-        dplyr::relocate(group, 1)
+    dplyr::relocate(group, 1)
 
   ret
 }
@@ -93,5 +88,6 @@ glance.varest <- function(x, ...) {
     logLik = s$logLik,
     nobs = x$obs,
     n = x$totobs,
-    na_types = "riii")
+    na_types = "riii"
+  )
 }
