@@ -1,5 +1,10 @@
 context("plm tidiers")
 
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
+
 skip_if_not_installed("plm")
 library(plm)
 
@@ -18,21 +23,17 @@ test_that("plm tidier arguments", {
 
 test_that("tidy.plm", {
   td <- tidy(fit, conf.int = TRUE)
-  tdq <- tidy(fit, conf.int = TRUE, quick = TRUE)
-  
   check_tidy_output(td)
-  check_tidy_output(tdq)
   check_dims(td, 4, 7)
 })
 
 test_that("glance.plm", {
   gl <- glance(fit)
   check_glance_outputs(gl)
-  check_dims(gl, expected_cols = 6)
+  check_dims(gl, expected_cols = 7)
 })
 
 test_that("augment.plm", {
-  
   check_augment_function(
     aug = augment.plm,
     model = fit,
@@ -40,4 +41,3 @@ test_that("augment.plm", {
     newdata = Produc
   )
 })
-
